@@ -28,6 +28,7 @@ import six.moves.urllib.parse as urlparse
 
 from ironic.common import exception
 from ironic.common.glance_service import service_utils
+from ironic.common.i18n import _
 from ironic.common import keystone
 from ironic.conf import CONF
 
@@ -183,6 +184,7 @@ class BaseImageService(object):
         :returns: A dict containing image metadata.
 
         :raises: ImageNotFound
+        :raises: ImageUnacceptable if the image status is not active
         """
         LOG.debug("Getting image metadata from glance. Image: %s",
                   image_href)
@@ -190,6 +192,11 @@ class BaseImageService(object):
 
         image = self.call(method, image_id)
 
+        if not service_utils.is_image_active(image):
+            raise exception.ImageUnacceptable(
+                image_id=image_id,
+                reason=_("The image is required to be in an active state."))
+
         if not service_utils.is_image_available(self.context, image):
             raise exception.ImageNotFound(image_id=image_id)
 
