@@ -47,8 +47,9 @@ DISK_LAYOUT_PARAMS = ('root_gb', 'swap_mb', 'ephemeral_gb')
 class InstanceImageCache(image_cache.ImageCache):
 
     def __init__(self):
+        master_path = CONF.pxe.instance_master_path or None
         super(self.__class__, self).__init__(
-            CONF.pxe.instance_master_path,
+            master_path,
             # MiB -> B
             cache_size=CONF.pxe.image_cache_size * 1024 * 1024,
             # min -> sec
